summaryrefslogtreecommitdiffstats
path: root/proto/rip/rip.c
diff options
context:
space:
mode:
authorPavel Machek <pavel@ucw.cz>2000-05-04 22:08:34 +0200
committerPavel Machek <pavel@ucw.cz>2000-05-04 22:08:34 +0200
commit9b63e3a58afe17b98eb7722e352984574846c22c (patch)
treebd24af007127c36af38e5524449ad83c316f7972 /proto/rip/rip.c
parentcf3d6470d7c8d401b162516ed7446c1d3866d5d3 (diff)
downloadbird-9b63e3a58afe17b98eb7722e352984574846c22c.tar
bird-9b63e3a58afe17b98eb7722e352984574846c22c.zip
Spelling fixes.
Diffstat (limited to 'proto/rip/rip.c')
-rw-r--r--proto/rip/rip.c10
1 files changed, 5 insertions, 5 deletions
diff --git a/proto/rip/rip.c b/proto/rip/rip.c
index f9a4483..0a1bdbc 100644
--- a/proto/rip/rip.c
+++ b/proto/rip/rip.c
@@ -31,7 +31,7 @@
* from two concurrent sends to one destination. Each &rip_interface has
* at most one &rip_connection.
*
* We are not going to honour requests for sending part of
* routing table. That would need to turn split horizon off,
* etc.
*
@@ -332,12 +332,12 @@ rip_process_packet( struct proto *p, struct rip_packet *packet, int num, ip_addr
switch( packet->heading.command ) {
case RIPCMD_REQUEST: DBG( "Asked to send my routing table\n" );
- if (P_CF->honour == HO_NEVER) {
+ if (P_CF->honor == HO_NEVER) {
log( L_REMOTE "They asked me to send routing table, but I was told not to do it" );
return 0;
}
- if ((P_CF->honour == HO_NEIGHBOUR) && (!neigh_find( p, &whotoldme, 0 ))) {
- log( L_REMOTE "They asked me to send routing table, but he is not my neighbour" );
+ if ((P_CF->honor == HO_NEIGHBOR) && (!neigh_find( p, &whotoldme, 0 ))) {
+ log( L_REMOTE "They asked me to send routing table, but he is not my neighbor" );
return 0;
}
rip_sendto( p, whotoldme, port, HEAD(P->interfaces) ); /* no broadcast */
@@ -353,7 +353,7 @@ rip_process_packet( struct proto *p, struct rip_packet *packet, int num, ip_addr
}
if (!neigh_find( p, &whotoldme, 0 )) {
- log( L_REMOTE "%I send me routing info but he is not my neighbour", whotoldme );
+ log( L_REMOTE "%I send me routing info but he is not my neighbor", whotoldme );
#if 0
return 0;
#else
@@ -31,7 +31,7 @@
* at most one &rip_connection.
*
- * We are not going to honour requests for sending part of
+ * We are not going to honor requests for sending part of
* routing table. That would need to turn split horizon off,
* etc.